"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FloatingWindow = void 0;
const React = require("react");
const Rect_1 = require("../Rect");
const Types_1 = require("../Types");
/** @internal */
const FloatingWindow = (props) => {
    const { title, id, url, rect, onCloseWindow, onSetWindow } = props;
    const popoutWindow = React.useRef(null);
    const timerId = React.useRef(null);
    const contentRef = React.useRef(null);
    React.useLayoutEffect(() => {
        if (timerId.current) {
            clearTimeout(timerId.current);
        }
        let isMounted = true;
        const r = rect || new Rect_1.Rect(0, 0, 100, 100);
        const styles = Array.from(window.document.styleSheets).reduce((result, styleSheet) => {
            let rules = undefined;
            try {
                rules = styleSheet.cssRules;
            }
            catch (e) {
                // styleSheet.cssRules can throw a security exception
            }
            try {
                return [
                    ...result,
                    {
                        href: styleSheet.href,
                        type: styleSheet.type,
                        rules: rules ? Array.from(rules).map((rule) => rule.cssText) : null,
                    },
                ];
            }
            catch (e) {
                return result;
            }
        }, []);
        popoutWindow.current = window.open(url, id, `left=${r.x},top=${r.y},width=${r.width},height=${r.height}`);
        if (popoutWindow.current !== null) {
            onSetWindow(id, popoutWindow.current);
            window.addEventListener("beforeunload", () => {
                if (popoutWindow.current) {
                    popoutWindow.current.close();
                    popoutWindow.current = null;
                }
            });
            popoutWindow.current.addEventListener("load", () => {
                if (isMounted) {
                    const popoutDocument = popoutWindow.current.document;
                    popoutDocument.title = title;
                    const popoutContent = popoutDocument.createElement("div");
                    popoutContent.className = Types_1.CLASSES.FLEXLAYOUT__FLOATING_WINDOW_CONTENT;
                    popoutDocument.body.appendChild(popoutContent);
                    contentRef.current = popoutContent;
                    copyStyles(popoutDocument, styles).then(() => {
                        // setContent(popoutContent); // Ne pas utiliser setContent avec createPortal désactivé
                    });
                    popoutWindow.current.addEventListener("beforeunload", () => {
                        onCloseWindow(id);
                    });
                }
            });
        }
        else {
            console.warn(`Unable to open window ${url}`);
            onCloseWindow(id);
        }
        return () => {
            isMounted = false;
            timerId.current = setTimeout(() => {
                if (popoutWindow.current) {
                    popoutWindow.current.close();
                    popoutWindow.current = null;
                }
            }, 0);
        };
    }, []);
    // Utiliser contentRef.current comme nécessaire dans le reste du code...
    return null;
};
exports.FloatingWindow = FloatingWindow;
/** @internal */
function copyStyles(doc, styleSheets) {
    const head = doc.head;
    const promises = [];
    for (const styleSheet of styleSheets) {
        if (styleSheet.href) {
            const styleElement = doc.createElement("link");
            styleElement.type = styleSheet.type;
            styleElement.rel = "stylesheet";
            styleElement.href = styleSheet.href;
            head.appendChild(styleElement);
            promises.push(new Promise((resolve) => {
                styleElement.onload = () => resolve(true);
            }));
        }
        else {
            if (styleSheet.rules) {
                const style = doc.createElement("style");
                for (const rule of styleSheet.rules) {
                    style.appendChild(doc.createTextNode(rule));
                }
                head.appendChild(style);
            }
        }
    }
    return Promise.all(promises);
}
//# sourceMappingURL=FloatingWindow.js.map